@@ -7,15 +7,15 @@
 # - output object with processed glmnet output
 
 
-Reg2Graph <- function(mgmobj) {
+Reg2Graph <- function(mgmobj, 
+                      thresholding=TRUE) {
   
-  # -------------------- Processing glmnet Output -------------------
-  
-  # Basic info from model object
+  # ----- Basic info from model object ------
   p <- length(mgmobj$call$type) # number of variables
   n <- mgmobj$call$n
-  d <- mgmobj$call$k - 1
   moderators <- mgmobj$call$moderators
+  d <- mgmobj$call$k - 1
+  if(!is.null(moderators)) d <- 2
   type <- mgmobj$call$type
   level <- mgmobj$call$level
   threshold <- mgmobj$call$threshold
@@ -26,40 +26,64 @@ Reg2Graph <- function(mgmobj) {
   ind_cat <- mgmobj$call$ind_cat
   ind_binary <- mgmobj$call$ind_binary
   
-  mSpec <- ifelse(class(moderators) %in% c("integer","numeric"), "vector", "matrix")
+  # Determine type of moderation specification (if applicable)
+  if(d < 2) {
+    mSpec <- NULL
+  } else {
+    if(any(class(moderators) %in% c("integer","numeric"))) mSpec <- "vector" # as vector
+    if(any(class(moderators) %in% "matrix")) mSpec <- "matrix"# as customary specified
+    if(mgmobj$call$k > 2) mSpec<- "fullk" # all HoIs up to order k
+  }
   
   
-  # browser()
+  # --------------------------------------------------------------------------------------------
+  # -------------------- Fill glmnet output into list-structure --------------------------------
+  # --------------------------------------------------------------------------------------------
   
-  # Storage
+  # ----- Storage -----
   Pars_ind <- list() # storage for interaction-indicators
-  Pars_values <- list() # storage for actual parameters associate for the interactions indexed in Pars_ind
+  Pars_values <- list() # storage for parameter estimates associated with the interactions indexed in Pars_ind
   mgmobj$intercepts <- vector('list', length = p)
+  v_d_v <- rep(NA, p)
   
-  
+  # ----- Loop over p variables -----
   for(v in 1:p) {
     
+    # print(v)
+    
     model_obj <- mgmobj$nodemodels[[v]]$model
+    predictor_set <- (1:p)[-v] # set of predictors for variable v (i.e., all others)
+    
+    # ----- Is variable v involved in higher-order / Moderation effects? ------
+    if(!is.null(moderators)) {
+      if(mSpec == "vector") ind_m <- TRUE
+      if(mSpec == "matrix") {
+        m_ind_m <- apply(moderators, 1, function(x) v %in% x)
+        ind_m <- any(m_ind_m)
+      }  
+      if(ind_m) d_v <- 2 else d_v <- 1
+    } else {
+      ind_m <- FALSE
+      d_v <- 1
+    }
+    
+    # if k>2 every variable v is involved in some HoI
+    if(mgmobj$call$k > 2){
+      d_v <- d
+      ind_m <- TRUE
+    } 
+    
     
     # ----- Create empty Storage for parameters -----
+    v_Pars_ind <- vector('list', length = d_v) #  1 = pairwise, 2 = 3-way, etc.
     
-    predictor_set <- (1:p)[-v] # set of predictors for variable v (all others)
-    
-    # A) Indicator Object for all possible interactions: List contains Matrix
-    v_Pars_ind <- vector('list', length = d) #  1 = pairwise, 2= threeway, etc.
-    
-    ## Create Indicator list for Present interactions (separate for k-order MGM and moderated MGM)
-    if(is.null(moderators)) {
+    if(!ind_m) {
       
-      # If there are no moderators: All interactions of specified degree (k)
-      for(ord in 1:d) v_Pars_ind[[ord]] <- t(combn(predictor_set, ord))
+      # Only pairwise interactions  
+      v_Pars_ind[[1]] <- t(combn(predictor_set, 1))
       
     } else {
       
-      d <- 2
-      
-      v_Pars_ind[[1]] <- matrix(predictor_set, ncol=1) # main effects
-      
       # Moderation effects
       if(mSpec == "vector") {
         
@@ -71,6 +95,8 @@ Reg2Graph <- function(mgmobj) {
         
         ind_mods <- ind_mods[!apply(ind_mods, 1, function(x) x[1] == x[2]), ] # remove rows with equal entries
         
+        v_Pars_ind[[1]] <- matrix(predictor_set, ncol = 1) # main effects
+        v_Pars_ind[[2]] <- ind_mods
       }
       
       if(mSpec == "matrix") {
@@ -78,22 +104,31 @@ Reg2Graph <- function(mgmobj) {
         ind_v_inMod <- as.logical(apply(moderators, 1, function(x) v %in% x  ))
         ind_mods <- t(apply(matrix(moderators[ind_v_inMod], ncol=3), 1, function(x) x[x!=v]))
         
+        v_Pars_ind[[1]] <- matrix(predictor_set, ncol = 1) # main effects
+        v_Pars_ind[[2]] <- ind_mods  
+        
+      }
+      
+      
+      
+      if(mSpec == "fullk") {
+        
+        for(ord in 1:d_v) {
+          v_Pars_ind[[ord]] <- t(combn(predictor_set, ord))
+        }
+        
       }
-
-      v_Pars_ind[[2]] <- ind_mods
-      # no interactions k > 2 allowed, if moderators are specified
       
     } # end if: moderators?
     
     # Make sure all entries of "v_Pars_ind" are matrices
-    for(j in 1:d) v_Pars_ind[[j]] <- matrix(as.matrix(v_Pars_ind[[j]]), ncol=j)
+    for(ord in 1:d_v) v_Pars_ind[[ord]] <- matrix(as.matrix(v_Pars_ind[[ord]]), ncol=ord)
     
     no_interactions <- unlist(lapply(v_Pars_ind, nrow))
     
     # B) Parameter Object: Same structure as (A), but now with a list entry for each matrix row
-    v_Pars_values <- vector('list', length = d)
-    for(ord in 1:d) v_Pars_values[[ord]] <- vector('list', length = no_interactions[ord])
-    
+    v_Pars_values <- vector('list', length = d_v)
+    for(ord in 1:d_v) v_Pars_values[[ord]] <- vector('list', length = no_interactions[ord])
     
     
     
@@ -113,19 +148,20 @@ Reg2Graph <- function(mgmobj) {
         interaction_names <- rownames(model_obj[[cat]])[-1] # -1 because we remove the intercept
         interaction_order <- str_count(interaction_names, ":") + 1 # get order of each interaction parameter; +1 to put on same scale as ord, so ord=2 = pairwise interaction
         
-        mgmobj$intercepts [[v]][[cat]] <- model_obj_i[1]
+        mgmobj$intercepts[[v]][[cat]] <- model_obj_i[1]
         
         # Thresholding:
-        # p = number of covariances, as it should be
-        model_obj_i_ni <- model_obj_i[-1] # remove intercept, this is no covariate
-        if(threshold == 'LW') tau <- sqrt(d) * sqrt(sum(model_obj_i_ni^2)) * sqrt(log(npar_standard[v]) / n)
-        if(threshold == 'HW') tau <- d * sqrt(log(npar_standard[v]) / n)
-        if(threshold == 'none') tau <- 0
-        model_obj_i[abs(model_obj_i) < tau] <- 0 # set all parameter estimates below threshold to zero
-        mgmobj$nodemodels[[v]]$tau <- tau # Save tau
+        if(thresholding) {
+          # p = number of covariances, as it should be
+          model_obj_i_ni <- model_obj_i[-1] # remove intercept, this is no covariate
+          if(threshold == 'LW') tau <- sqrt(d_v) * sqrt(sum(model_obj_i_ni^2)) * sqrt(log(npar_standard[v]) / n)
+          if(threshold == 'HW') tau <- d_v * sqrt(log(npar_standard[v]) / n)
+          if(threshold == 'none') tau <- 0
+          model_obj_i[abs(model_obj_i) < tau] <- 0 # set all parameter estimates below threshold to zero
+          mgmobj$nodemodels[[v]]$tau <- tau # Save tau
+        }
         
-        
-        for(ord in 1:d) {
+        for(ord in 1:d_v) {
           
           part_ord <- model_obj_i[-1][ord == interaction_order] # parameters for interaction of order = ord+1
           gotThemall <- rep(TRUE, length(part_ord)) # sanity check: did I copy all parameters
@@ -144,7 +180,7 @@ Reg2Graph <- function(mgmobj) {
                                                            fixed = TRUE) # not only single chars have to be contained, but exact order)
             select_int <- rowSums(find_int_dummy) == ord # because threeway interaction has 2 predictors; ord = order of interactions in joint distribution
             
-            # fill in paramters + rownames into list
+            # fill in parameters + rownames into list
             parmat <- matrix(part_ord[select_int], ncol = 1)
             rownames(parmat) <- int_names_ord[select_int]
             v_Pars_values[[ord]][[t]][[cat]] <- parmat
@@ -166,20 +202,20 @@ Reg2Graph <- function(mgmobj) {
       interaction_names <- rownames(model_obj)[-1] # -1 because we remove the intercept
       interaction_order <- str_count(interaction_names, ":") + 1 # on same scale as ord, so ord=2 = pairwise interaction
       
-      mgmobj$intercepts [[v]] <- model_obj_i[1]
-      
-      # browser()
+      mgmobj$intercepts[[v]] <- model_obj_i[1]
       
       # Thresholding:
-      # p = number of covariances, as it should be
-      model_obj_i_ni <- model_obj_i[-1] # remove intercept, this is no covariate
-      if(threshold == 'LW') tau <- sqrt(d) * sqrt(sum(model_obj_i_ni^2)) * sqrt(log(npar_standard[v]) / n)
-      if(threshold == 'HW') tau <- d * sqrt(log(npar_standard[v]) / n)
-      if(threshold == 'none') tau <- 0
-      model_obj_i[abs(model_obj_i) < tau] <- 0 # set all parameter estimates below threshold to zero
-      mgmobj$nodemodels[[v]]$tau <- tau # Save tau
+      if(thresholding) {
+        # p = number of covariances, as it should be
+        model_obj_i_ni <- model_obj_i[-1] # remove intercept, this is no covariate
+        if(threshold == 'LW') tau <- sqrt(d_v) * sqrt(sum(model_obj_i_ni^2)) * sqrt(log(npar_standard[v]) / n)
+        if(threshold == 'HW') tau <- d_v * sqrt(log(npar_standard[v]) / n)
+        if(threshold == 'none') tau <- 0
+        model_obj_i[abs(model_obj_i) < tau] <- 0 # set all parameter estimates below threshold to zero
+        mgmobj$nodemodels[[v]]$tau <- tau # Save tau
+      }
       
-      for(ord in 1:d) {
+      for(ord in 1:d_v) {
         
         if(no_interactions[ord] > 0) { # can be zero for moderated MGMs
           
@@ -204,6 +240,7 @@ Reg2Graph <- function(mgmobj) {
             rownames(parmat) <- int_names_ord[select_int]
             v_Pars_values[[ord]][[t]] <- parmat
             
+            # Sanity check
             gotThemall[select_int == TRUE] <- FALSE
             
           }
@@ -219,16 +256,16 @@ Reg2Graph <- function(mgmobj) {
     Pars_ind[[v]] <- v_Pars_ind
     Pars_values[[v]] <- v_Pars_values
     
+    # record max order of interaction of node v
+    v_d_v[v] <- d_v
+    
   } # end for: v
   
   
-  # browser()
-  
   # --------------------------------------------------------------------------------------------
   # -------------------- Postprocess Regression Estimates into (Factor) Graph Structure --------
   # --------------------------------------------------------------------------------------------
   
-  
   # ----- Reduce to 1 parameter per Factor, apply AND rule and get sign -----
   
   # Combine interactions from all neighborhood regressions in one structure
@@ -245,40 +282,48 @@ Reg2Graph <- function(mgmobj) {
   Pars_values_flip <- vector('list', length = d)
   Pars_values_flip <- lapply(Pars_values_flip, function(x) dummy_list_flip)
   
-  
   # Reordering so I can use do.call() below on inner list level
   for(v in 1:p) {
-    for(ord in 1:d) {
+    for(ord in 1:v_d_v[v]) {
       
       # Reordering indicator list
       Pars_ind_part <- Pars_ind[[v]][[ord]]
       colnames(Pars_ind_part) <- NULL
-      Pars_ind_part <- as.matrix(Pars_ind_part)
       
-      Pars_ind[[v]][[ord]] <- cbind(rep(v, nrow(Pars_ind_part)), Pars_ind_part)
-      Pars_ind_flip[[ord]][[v]] <- Pars_ind[[v]][[ord]]
+      # Are there HoIs with d>1?
+      if(!is.null(Pars_ind_part)) 
+      {
+        Pars_ind_part <- as.matrix(Pars_ind_part)
+        Pars_ind[[v]][[ord]] <- cbind(rep(v, nrow(Pars_ind_part)), Pars_ind_part)
+        Pars_ind_flip[[ord]][[v]] <- Pars_ind[[v]][[ord]]
+        
+        # Reordering value list
+        Pars_values_flip[[ord]][[v]] <- Pars_values[[v]][[ord]] 
+        
+      } else {
+        Pars_ind_flip[[ord]][[v]] <- NULL
+        Pars_values_flip[[ord]][[v]] <- NULL
+      }
       
-      # Reordering value list
-      Pars_values_flip[[ord]][[v]] <- Pars_values[[v]][[ord]]
-      
-    }
-  }
+    } # end for : ord
+  } # end for: v
   
   # Collapse indicator list across nodes
   Pars_ind_flip_red <- lapply(Pars_ind_flip, function(x) do.call(rbind, x)  )
   # Collapse value list across nodes
   Pars_values_flip_red <- lapply(Pars_values_flip, function(x) do.call(c, x))
   
-  # browser()
   
+
   # 1) Select each interaction
   
-  # Compute number of interactions for each order
-  #     Note that we could take this information also from the design matrices; however, we compute it theoretically as a sanity check
+  ## Compute number of interactions for each order
+  # Note that we could take this information also from the design matrices; however, we compute it theoretically as a sanity check
+  
+  # Moderation effects in the model?
   n_terms_d <- rep(NA, d)
-  if(is.null(moderators)) {
-    for(ord in 1:d) n_terms_d[ord] <- choose(p, ord+1)
-  } else {
+  
+  if(!is.null(moderators)) {
     n_terms_d[1] <- choose(p, 1+1) # all pairwise interactions
     
     # Select moderation terms: Standard specification
@@ -294,9 +339,14 @@ Reg2Graph <- function(mgmobj) {
     if(mSpec == "matrix") {
       mod_terms3 <- mgmobj$call$moderators
     }
-    
     n_terms_d[2] <- nrow(mod_terms3) # ok to have interactions double; will remove them below using FlagSymmetricFast()
-  }
+    
+  } else {
+    
+    for(ord in 1:d) n_terms_d[ord] <- choose(p, ord+1)  # this for loop is actually unnecessary; but who's checking? ;)
+    
+  } # end ifelse: moderation?
+  
   
   # Set up target data structure
   l_factors <- list() # saves all unique interavtions
@@ -308,7 +358,7 @@ Reg2Graph <- function(mgmobj) {
   
   l_factor_par_full <- l_factor_par_AggNodewise <- l_factor_par_SignNodewise <- l_factor_par # for un-aggregated parameter estimates
   
-  # Define set of continous and binary variables: for interactions between these we can assign a sign
+  # Define set of continuous and binary variables: for interactions between these we can assign a sign
   # Depends on binarySign
   if(binarySign) {
     set_signdefined <- c(which(type == 'p'), which(type == 'g'), ind_cat[ind_binary])
@@ -317,7 +367,6 @@ Reg2Graph <- function(mgmobj) {
   }
   
   
-  
   # Loop over: order of interactions (ord = 1 = pairwise)
   for(ord in 1:d) {
     
@@ -446,8 +495,6 @@ Reg2Graph <- function(mgmobj) {
   mgmobj$interactions$weights <- l_factor_par_full_nz
   mgmobj$interactions$signs <- l_sign_par_nz
   
-  # browser()
-  
   
   # ---------- Fill into p x p Matrix ---------
   
